@@ -34,6 +34,8 @@
 
 #include "GNOME_Media_CDDBSlave2.h"
 
+extern void destroy_cache_hashTable (void);
+
 static GNOME_Media_CDDBTrackEditor track_editor = CORBA_OBJECT_NIL;
 
 static gboolean position_auto_update=TRUE;
@@ -504,10 +506,9 @@ status_ok (GnomeCD *gcd,
 
 	case GNOME_CDROM_AUDIO_PLAY:
 		/* Change the play button to pause */
-		aob = gtk_widget_get_accessible (GTK_WIDGET (gcd->play_b));
-		atk_object_set_name (aob, _("Pause"));
-
 		if (gcd->current_image != gcd->pause_image) {
+			aob = gtk_widget_get_accessible (GTK_WIDGET (gcd->play_b));
+			atk_object_set_name (aob, _("Pause"));
 			gtk_container_remove (GTK_CONTAINER (gcd->play_b),
 					      gcd->play_image);
 			gtk_container_add (GTK_CONTAINER (gcd->play_b),
@@ -567,9 +568,9 @@ status_ok (GnomeCD *gcd,
 
 	case GNOME_CDROM_AUDIO_PAUSE:
 		/* Change the play button to pause */
-		aob = gtk_widget_get_accessible (GTK_WIDGET (gcd->play_b));
-		atk_object_set_name (aob, _("Play"));
 		if (gcd->current_image != gcd->play_image) {
+			aob = gtk_widget_get_accessible (GTK_WIDGET (gcd->play_b));
+			atk_object_set_name (aob, _("Play"));
 			gtk_container_remove (GTK_CONTAINER (gcd->play_b),
 					      gcd->pause_image);
 			gtk_container_add (GTK_CONTAINER (gcd->play_b),
@@ -714,13 +715,16 @@ cd_status_changed_cb (GnomeCDRom *cdrom,
 	if (gcd->not_ready == TRUE) {
 		return;
 	}
-	
+
 	switch (status->cd) {
 	case GNOME_CDROM_STATUS_OK:
                 /* does everything when the state is ok */
 		status_ok (gcd, status);
                 /* next is sensitive when this is not the last track */
-		if (status->track >= gcd->disc_info->ntracks)
+		/* but gcd->disc_info might be NULL when
+                 * this gets called on startup but we haven't looked at the
+                 * disc yet */
+		if (gcd->disc_info && status->track >= gcd->disc_info->ntracks)
                        gtk_widget_set_sensitive (gcd->next_b, FALSE);
 		else
                        gtk_widget_set_sensitive (gcd->next_b, TRUE);
@@ -987,7 +991,7 @@ open_preferences (GtkWidget *widget,
 	static GtkWidget *dialog = NULL;
 
 	if (dialog == NULL) {
-		dialog = preferences_dialog_show (gcd, FALSE);
+		dialog = preferences_dialog_show (gcd);
 		g_signal_connect (G_OBJECT (dialog), "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &dialog);
 	} else {
