@@ -294,7 +294,7 @@ cdrom_set_device (GnomeCDRom *cdrom,
 		  const char *device,
 		  GError    **error)
 {
-	GnomeCDRomStatus *status;
+	/*GnomeCDRomStatus *status;*/
 	GnomeCDRomPrivate *priv;
 
 	g_return_val_if_fail (cdrom != NULL, FALSE);
@@ -766,7 +766,7 @@ not_ready_status_new (void)
 static gboolean
 timeout_update_cd (gpointer data)
 {
-	GError *error;
+	GError *error = NULL;
 	GnomeCDRom *cdrom = data;
 	GnomeCDRomStatus *status;
 	GnomeCDRomPrivate *priv;
@@ -803,6 +803,8 @@ timeout_update_cd (gpointer data)
 		if (priv->update != GNOME_CDROM_UPDATE_NEVER)
 			gnome_cdrom_status_changed (GNOME_CDROM (cdrom), priv->recent_status);
 
+		//g_free (status);
+
 	} else {
 		if (gnome_cdrom_status_equal (status, priv->recent_status)) {
 			if (priv->update == GNOME_CDROM_UPDATE_CONTINOUS)
