@@ -262,23 +262,6 @@ make_button_from_widget (GnomeCD *gcd,
 	return button;
 }
 
-static GtkWidget *
-make_button_from_pixbuf (GnomeCD *gcd,
-			 GdkPixbuf *pixbuf,
-			 GCallback func,
-			 const char *tooltip,
-			 const char *shortname)
-{
-	GtkWidget *pixmap;
-
-	g_return_val_if_fail (gcd != NULL, NULL);
-	g_return_val_if_fail (pixbuf != NULL, NULL);
-		
-	pixmap = gtk_image_new_from_pixbuf (pixbuf);
-
-	return make_button_from_widget (gcd, pixmap, func, tooltip, shortname);
-}
-
 static GtkWidget *
 make_button_from_stock (GnomeCD *gcd,
 			const char *stock,
@@ -421,7 +404,7 @@ show_error (GtkWidget	*dialog,
 
 	case 2:
 		gtk_widget_destroy (dialog);
-		dialog = GTK_WIDGET(preferences_dialog_show (gcd, TRUE));
+		dialog = GTK_WIDGET(preferences_dialog_show (gcd));
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -479,7 +462,7 @@ init_player (const char *device_override)
 		switch (gtk_dialog_run (GTK_DIALOG (dialog))) {
 		case 1:
 			gtk_widget_destroy (dialog);
-			dialog = GTK_WIDGET(preferences_dialog_show (gcd, TRUE));
+			dialog = GTK_WIDGET(preferences_dialog_show (gcd));
 
 			/* Don't care what it returns */
 			gtk_dialog_run (GTK_DIALOG (dialog));
@@ -764,7 +747,7 @@ save_session(GnomeClient        *client,
     return TRUE;
 }
 
-static gint client_die(GnomeClient *client,
+static void client_die(GnomeClient *client,
 		       GnomeCD *gcd)
 {
 	gtk_widget_destroy (gcd->window);
@@ -820,7 +803,7 @@ register_stock_icons (void)
 int 
 main (int argc, char *argv[])
 {
-	static const struct poptOption cd_popt_options [] = {
+	static struct poptOption cd_popt_options [] = {
 		{ "device", '\0', POPT_ARG_STRING, &cd_option_device, 0,
 		  N_("CD device to use"), NULL },
 		{ "unique", '\0', POPT_ARG_NONE, &cd_option_unique, 0,
