@@ -40,6 +40,9 @@
 #include "gnome-recorder.h"
 #include "gsr-window.h"
 
+extern GtkWidget * gsr_open_window (const char *filename);
+extern void gsr_quit (void);
+
 enum {
 	PROP_0,
 	PROP_LOCATION
@@ -100,6 +103,7 @@ struct _GSRWindowPrivate {
 };
 
 static GSRWindowPipeline * make_record_pipeline    (GSRWindow         *window);
+static GSRWindowPipeline * make_play_pipeline      (GSRWindow         *window);
 static void                gsr_window_init         (GSRWindow         *window);
 static void                gsr_window_class_init   (GSRWindowClass    *klass);
 static void                gsr_window_finalize     (GObject           *object);
@@ -360,31 +364,6 @@ file_open (BonoboUIComponent *uic,
 	gtk_widget_show (file_chooser);
 }
 
-enum mimetype {
-	MIME_TYPE_WAV,
-	MIME_TYPE_MP3,
-	MIME_TYPE_OGG,
-	MIME_TYPE_FLAC
-};
-
-static GstElement *
-get_encoder_for_mimetype (enum mimetype mime)
-{
-	switch (mime) {
-	case MIME_TYPE_WAV:
-		return gst_element_factory_make ("wavenc", "encoder");
-
-	case MIME_TYPE_MP3:
-		return gst_element_factory_make ("lame", "encoder");
-
-	case MIME_TYPE_OGG:
-		return gst_element_factory_make ("vorbisenc", "encoder");
-
-	case MIME_TYPE_FLAC:
-		return gst_element_factory_make ("flacenc", "encoder");
-	}
-}
-
 struct _eos_data {
 	GSRWindow *window;
 	char *location;
@@ -424,24 +403,6 @@ eos_done (struct _eos_data *ed)
 	return FALSE;
 }
 
-static void
-save_sink_eos_cb (GstElement *element,
-		  GSRWindow *window)
-{
-	char *filename;
-	struct _eos_data *ed;
-
-	ed = g_new (struct _eos_data, 1);
-	ed->window = window;
-	ed->pipeline = GST_ELEMENT (gst_element_get_parent (element));
-	g_object_get (G_OBJECT (element),
-		      "location", &ed->location,
-		      NULL);
-
-	/*g_idle_add ((GSourceFunc) eos_done, ed);*/
-	eos_done (ed);
-}
-
 static GstElement *
 gst_element_get_child (GstElement* element, const gchar *name)
 {
@@ -911,13 +872,6 @@ file_close (BonoboUIComponent *uic,
 	gsr_window_close (window);
 }
 
-static void
-close_window (GSRWindow *window,
-	      gpointer data)
-{
-	gsr_window_close (window);
-}
-
 static void
 file_quit (BonoboUIComponent *uic,
 	   GSRWindow *window,
@@ -983,6 +937,16 @@ media_play (BonoboUIComponent *uic,
 	if (priv->has_file == FALSE)
 		return;
 
+	if (priv->play) {
+		gst_element_set_state (priv->play->pipeline, GST_STATE_NULL);
+		g_object_unref (priv->play->pipeline);
+	}
+	priv->play = make_play_pipeline (window);
+
+	g_object_set (G_OBJECT (window->priv->play->src),
+		      "location", priv->filename,
+		      NULL);
+
 	if (priv->record && gst_element_get_state (priv->record->pipeline) == GST_STATE_PLAYING) {
 		gst_element_set_state (priv->record->pipeline, GST_STATE_READY);
 	}
@@ -1007,9 +971,8 @@ media_stop (BonoboUIComponent *uic,
 		g_free (priv->working_file);
 		priv->working_file = g_strdup (priv->record_filename);
 
-		g_object_set (G_OBJECT (priv->play->src),
-			      "location", priv->working_file,
-			      NULL);
+		g_free (priv->filename);
+		priv->filename = g_strdup (priv->record_filename);
 
 		priv->dirty = TRUE;
 		priv->has_file = TRUE;
@@ -1100,20 +1063,20 @@ seek_to (GtkRange *range,GdkEventButton *gdkevent,
 	gint64 time;
 	GstEvent *event;
 	GstElementState old_state;
-	gboolean ret;
 
 	old_state = gst_element_get_state (window->priv->play->pipeline);
-	if (old_state == GST_STATE_READY) {
-		return;
+	if (old_state == GST_STATE_READY || old_state == GST_STATE_NULL) {
+		return FALSE;
 	}
 
 	gst_element_set_state (window->priv->play->pipeline, GST_STATE_PAUSED);
 	time = ((value / 100) * window->priv->len_secs) * GST_SECOND;
 
 	event = gst_event_new_seek (GST_FORMAT_TIME | GST_SEEK_FLAG_FLUSH, time);
-	ret = gst_element_send_event (window->priv->play->sink, event);
+	gst_element_send_event (window->priv->play->sink, event);
 	gst_element_set_state (window->priv->play->pipeline, old_state);
 	window->priv->seek_in_progress = FALSE;
+
 	return FALSE;
 }
 
@@ -1361,11 +1324,10 @@ record_start (gpointer user_data)
 {
 	GSRWindow *window = GSR_WINDOW (user_data);
 
-	if (window->priv->len_secs == 0) {
-		window->priv->get_length_attempts = 16;
-		g_timeout_add (200, (GSourceFunc) record_tick_callback, window);
-	}
-	
+
+	window->priv->get_length_attempts = 16;
+	g_timeout_add (200, (GSourceFunc) record_tick_callback, window);
+
 	CMD_SET_SENSITIVE (window, "MediaStop", "1");
 	CMD_SET_SENSITIVE (window, "MediaPlay", "0");
 	CMD_SET_SENSITIVE (window, "MediaRecord", "0");
@@ -1416,7 +1378,7 @@ make_record_pipeline (GSRWindow *window)
 	GSRWindowPipeline *pipeline;
 	gint32 id;
 	GMAudioProfile *profile;
-	gchar *pipeline_desc;
+	gchar *pipeline_desc, *source;
 	GstElement *encoder;
 	
 	pipeline = g_new (GSRWindowPipeline, 1);
@@ -1431,14 +1393,26 @@ make_record_pipeline (GSRWindow *window)
 			  G_CALLBACK (pipeline_error_cb), window);
 	
         profile = gm_audio_profile_choose_get_active (window->priv->profile);
+	source = gst_gconf_get_string ("default/audiosrc");
+	if (!source) {
+		show_error_dialog (NULL, _("There is no default GStreamer "
+				   "audio input element set - please install "
+				   "the GStreamer-GConf schemas or set one "
+				   "manually"));
+		return NULL;
+	}
+
 	pipeline_desc = g_strdup_printf ("%s ! audioconvert ! %s",
 					 gst_gconf_get_string ("default/audiosrc"),
 					 gm_audio_profile_get_pipeline (profile));
+	g_free (source);
 	
 	encoder = gst_gconf_render_bin_from_description (pipeline_desc);
 	g_free (pipeline_desc);
 	if (!encoder) {
-		g_error ("Could not construct pipeline");
+		show_error_dialog (NULL, _("Failed to create GStreamer "
+				   "encoder elements - check your encoding "
+				   "setup"));
 		return NULL;
 	}
 	gst_bin_add (GST_BIN (pipeline->pipeline), encoder);
@@ -1446,14 +1420,17 @@ make_record_pipeline (GSRWindow *window)
 	pipeline->sink = gst_element_factory_make ("filesink", "sink");
 	if (!pipeline->sink)
 	{
-		g_error ("Could not find filesink element");
+		show_error_dialog (NULL, _("Could not find GStreamer filesink"
+				   " plugin - please install it"));
 		return NULL;
 	}
 	gst_bin_add (GST_BIN (pipeline->pipeline), pipeline->sink);
 	
 	if (!gst_element_link (encoder, pipeline->sink))
 	{
-		g_error ("Could not link elements");
+		show_error_dialog (NULL, _("Failed to link encoder elements "
+				   "with file output element - you probably "
+				   "selected an invalid encoder"));
 		return NULL;
 	}
 	
@@ -1663,7 +1640,7 @@ gsr_window_init (GSRWindow *window)
 	bonobo_ui_component_thaw (priv->ui_component, NULL);
 
 	/* Make the pipelines */
-	priv->play = make_play_pipeline (window);
+	priv->play = NULL;
 	priv->record = NULL; 
 
 	priv->len_secs = 0;
@@ -1740,9 +1717,6 @@ gsr_window_set_property (GObject      *object,
 		g_free (title);
 		g_free (short_name);
 				      
-		g_object_set (G_OBJECT (window->priv->play->src),
-			      "location", priv->filename,
-			      NULL);
 		
 		CMD_SET_SENSITIVE (window, "MediaPlay", window->priv->has_file ? "1" : "0");
 		CMD_SET_SENSITIVE (window, "MediaStop", "0");
